pub struct CollatorService<Block: BlockT, BS, RA> { /* private fields */ }Expand description
The CollatorService provides common utilities for parachain consensus and authoring.
This includes logic for checking the block status of arbitrary parachain headers
gathered from the relay chain state, creating full Collations to be shared with validators,
and distributing new parachain blocks along the network.
Implementations
Sourceimpl<Block, BS, RA> CollatorService<Block, BS, RA>where
Block: BlockT,
BS: BlockBackend<Block>,
RA: ProvideRuntimeApi<Block>,
RA::Api: CollectCollationInfo<Block>,
impl<Block, BS, RA> CollatorService<Block, BS, RA>where
Block: BlockT,
BS: BlockBackend<Block>,
RA: ProvideRuntimeApi<Block>,
RA::Api: CollectCollationInfo<Block>,
Sourcepub fn new(
block_status: Arc<BS>,
announce_block: Arc<dyn Fn(Block::Hash, Option<Vec<u8>>) + Send + Sync>,
runtime_api: Arc<RA>,
) -> Self
pub fn new( block_status: Arc<BS>, announce_block: Arc<dyn Fn(Block::Hash, Option<Vec<u8>>) + Send + Sync>, runtime_api: Arc<RA>, ) -> Self
Create a new instance.
Sourcepub fn check_block_status(
&self,
hash: Block::Hash,
header: &Block::Header,
) -> bool
pub fn check_block_status( &self, hash: Block::Hash, header: &Block::Header, ) -> bool
Checks the status of the given block hash in the Parachain.
Returns true if the block could be found and is good to be build on.
Sourcepub fn fetch_collation_info(
&self,
block_hash: Block::Hash,
header: &Block::Header,
) -> Result<Option<(CollationInfo, u32)>, ApiError>
pub fn fetch_collation_info( &self, block_hash: Block::Hash, header: &Block::Header, ) -> Result<Option<(CollationInfo, u32)>, ApiError>
Fetch the collation info from the runtime.
Returns Ok(Some((CollationInfo, ApiVersion))) on success, Err(_) on error or Ok(None)
if the runtime api isn’t implemented by the runtime. ApiVersion being the version of the
CollectCollationInfo runtime api.